import httpRequest from '@/utils/axios'

// 获取视频列表
export function getVideoList(params: {
  tab: string
  status?: string
  authorized?: string
  classification?: string
  page?: number
  page_size?: number
}) {
  return httpRequest.get('/api/resource/v1/resource/video/list', { params })
}
// 获取视频列表
export function getCourseList(params: {
  tab: string
  name?: string
  authorized?: string
  page?: number
  page_size?: number
}) {
  return httpRequest.get('/api/resource/v1/course/course/list', { params })
}

// 获取课程统计
export function getCourseStatistics() {
  return httpRequest.get('/api/resource/v1/course/course/statistics')
}

// 获取教案列表
export function getLessonList(params?: {
  tab: string
  status?: string
  authorized?: string
  classification?: string
  page?: number
  ['per-page']?: number
}) {
  return httpRequest.get('/api/resource/v1/resource/lesson-plan/list', { params })
}
// 获取其他资料列表
export function getOtherList(params?: {
  tab: string
  status?: string
  authorized?: string
  classification?: string
  page?: number
  ['per-page']?: number
}) {
  return httpRequest.get('/api/resource/v1/resource/other-information/list', { params })
}
// 试卷搜索
export function gatExamList(data: {
  nonce: string
  timestamp: string
  signature: string
  paper_title: string
  limit: string
  is_all: number
  project_prefix: string
}) {
  return httpRequest.post('/api/qbs/api/v1/question-papers/search', data)
}

// 获取视频详情
export function getVideoDetails(params: { id: string }) {
  return httpRequest.get('/api/resource/v1/resource/video/view', { params })
}
// 获取课件详情
export function getCourseDetails(params: { id: string }) {
  return httpRequest.get('/api/resource/v1/resource/courseware/view', { params })
}
// 获取教案详情
export function getLessonDetails(params: { id: string }) {
  return httpRequest.get('/api/resource/v1/resource/lesson-plan/view', { params })
}
// 章节结构调整
export function dragChapterList(data: { course_id: string; id: string; brother_id: string; type: string }) {
  return httpRequest.post('/api/resource/v1/course/course/drag', data)
}

// 更新视频
export function updateVideo(data: {
  id: string
  name: string
  classification: string
  knowledge_points?: string
  cover?: string
}) {
  return httpRequest.post('/api/resource/v1/resource/video/update', data)
}

// 部门共享
export function setDepartment(data: { id: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/set-department', data)
}

// 平台共享
export function setPlatform(data: { id: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/set-platform', data)
}

// 上下线
export function setStatus(data: { id: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/set-status', data)
}

// 更改负责人
export function setBelong(data: { id: string; belong_operator: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/set-belong', data)
}

// 获取视频详情
export function getVideoPpt(params: { id: string }) {
  return httpRequest.get('/api/resource/v1/resource/video/get-ppt', { params })
}

// 创建课件
export function createPpt(data: { id: string; ppts: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/create-ppt', data)
}

// 编辑课件
export function updatePpt(data: { id: string; ppt_id: string; name: string; point: string; url: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/update-ppt', data)
}

// 获取章节
export function deletePpt(data: { course_id: string; type: string }) {
  return httpRequest.post('/api/resource/v1/resource/video/delete-ppt', data)
}

// 获取章节
export function getCharacter(params: { course_id: string; type: string }) {
  return httpRequest.get('/api/resource/v1/course/course/chapters', { params })
}
// 新建章节
export function createCharacter(data: {
  course_id: string
  resource_type: string
  name: string
  parent_id?: string
  resource_id?: string
}) {
  return httpRequest.post('/api/resource/v1/course/course/create-chapter', data)
}
// 章节修改
export function editCharacter(data: { id: string; course_id: string; name: string; resource_id: string }) {
  return httpRequest.post('/api/resource/v1/course/course/update-chapter', data)
}
// 章节删除
export function delCharacter(data: { id: string; course_id: string }) {
  return httpRequest.post('/api/resource/v1/course/course/delete-chapter', data)
}
// 直播列表
export function getLiveList(params: { name: string; page?: number; ['page_size']?: number }) {
  return httpRequest.get('/api/resource/v1/course/course/search-live', { params })
}
